Summary: Enhanced system logging and kernel message trapping daemon
Name: rsyslog
Version: 5.6.4
Release: 1
License: GPLv3+
Group: System Environment/Daemons
URL: http://www.rsyslog.com/
Source0: http://www.rsyslog.com/files/download/rsyslog/%{name}-%{version}.tar.gz
Source1: %{name}.init
Source2: %{name}.conf
Source3: %{name}.sysconfig
Patch0: %{name}-%{version}-aix.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires: gnutls-devel >= 2.6.6-2
BuildRequires: librelp-devel >= 1.0.0-1
BuildRequires: krb5-devel >= 1.8.3-1
BuildRequires: zlib-devel

Requires: zlib

Provides: syslog

%description
Rsyslog is an enhanced, multi-threaded syslog daemon. It supports MySQL,
syslog/TCP, RFC 3195, permitted sender lists, filtering on any message part,
and fine grain output format control. It is compatible with stock sysklogd
and can be used as a drop-in replacement. Rsyslog is simple to set up, with
advanced features suitable for enterprise-class, encryption-protected syslog
relay chains.


%package gssapi
Summary: GSSAPI authentication and encryption support for rsyslog
Group: System Environment/Daemons
Requires: %{name} = %{version}-%{release}
BuildRequires: krb5-devel >= 1.8.3-1
Requires: krb5-libs >= 1.8.3-1

%description gssapi
The rsyslog-gssapi package contains the rsyslog plugins which support GSSAPI 
authentication and secure connections. GSSAPI is commonly used for Kerberos 
authentication.


%package relp
Summary: RELP protocol support for rsyslog
Group: System Environment/Daemons
Requires: %{name} = %{version}-%{release}
BuildRequires: librelp-devel >= 1.0.0-1 
Requires: librelp >= 1.0.0-1 

%description relp
The rsyslog-relp package contains the rsyslog plugins that provide
the ability to receive syslog messages via the reliable RELP
protocol. 


%package gnutls
Summary: TLS protocol support for rsyslog
Group: System Environment/Daemons
Requires: %{name} = %{version}-%{release}
BuildRequires: gnutls-devel >= 2.6.6-2
Requires: gnutls >= 2.6.6-2

%description gnutls
The rsyslog-gnutls package contains the rsyslog plugins that provide the
ability to receive syslog messages via upcoming syslog-transport-tls
IETF standard protocol.


%prep
%setup -q
%patch0


%build
export CC="xlc_r"

export CFLAGS="$CFLAGS -DSYSLOGD_PIDNAME=\\\"rsyslogd.pid\\\""

./configure \
    --prefix=%{_prefix} \
    --mandir=%{_mandir} \
    --infodir=%{_infodir} \
    --enable-shared --disable-static \
    --enable-regexp \
    --enable-zlib \
    --enable-gssapi-krb5 \
    --enable-pthreads \
    --enable-unlimited-select \
    --enable-gnutls \
    --enable-mail \
    --enable-relp \
    --disable-rfc3195 \
    --disable-testbench \
    --enable-imfile

make %{?_smp_mflags}


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}
make DESTDIR=${RPM_BUILD_ROOT} install

/usr/bin/strip ${RPM_BUILD_ROOT}%{_sbindir}/* || :

(
  cd ${RPM_BUILD_ROOT}%{_libdir}/%{name}
  /usr/bin/rm -f *.la

  for f in *.a ; do
      /usr/bin/ar -X32 -x ${f}
  done

  /usr/bin/rm -f *.a
)

mkdir -p ${RPM_BUILD_ROOT}/etc/rc.d/init.d
mkdir -p ${RPM_BUILD_ROOT}/etc/rc.d/rc2.d
mkdir -p ${RPM_BUILD_ROOT}/etc/rc.d/rc3.d
cp %{SOURCE1} ${RPM_BUILD_ROOT}/etc/rc.d/init.d/%{name}
chmod 0755 ${RPM_BUILD_ROOT}/etc/rc.d/init.d/%{name}
ln -sf '../init.d/rsyslog' ${RPM_BUILD_ROOT}/etc/rc.d/rc2.d/S%{name}
ln -sf '../init.d/rsyslog' ${RPM_BUILD_ROOT}/etc/rc.d/rc2.d/K%{name}
ln -sf '../init.d/rsyslog' ${RPM_BUILD_ROOT}/etc/rc.d/rc3.d/S%{name}
ln -sf '../init.d/rsyslog' ${RPM_BUILD_ROOT}/etc/rc.d/rc3.d/K%{name}

mkdir -p ${RPM_BUILD_ROOT}/etc/%{name}.d
cp %{SOURCE2} ${RPM_BUILD_ROOT}/etc/%{name}.d/%{name}.conf
chmod 0644 ${RPM_BUILD_ROOT}/etc/%{name}.d/%{name}.conf

mkdir -p ${RPM_BUILD_ROOT}/etc/sysconfig
cp %{SOURCE3} ${RPM_BUILD_ROOT}/etc/sysconfig/%{name}
chmod 0644 ${RPM_BUILD_ROOT}/etc/sysconfig/%{name}

mkdir -p ${RPM_BUILD_ROOT}/var/run
chmod 0755 ${RPM_BUILD_ROOT}/var/run


%preun
if [ $1 = 0 ]; then
    /etc/rc.d/init.d/%{name} stop >/dev/null 2>&1 ||:
fi


%postun
if [ "$1" -ge "1" ]; then
    /etc/rc.d/init.d/%{name} condrestart > /dev/null 2>&1 ||:
fi


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system,-)
%doc AUTHORS COPYING NEWS README ChangeLog doc/*html
%config(noreplace) /etc/sysconfig/%{name}
%dir /etc/%{name}.d
%config(noreplace) /etc/%{name}.d/%{name}.conf
%{_sbindir}/rsyslogd
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/imfile.so
%{_libdir}/%{name}/imklog.so
%{_libdir}/%{name}/immark.so
%{_libdir}/%{name}/imtcp.so
%{_libdir}/%{name}/imudp.so
%{_libdir}/%{name}/imuxsock.so
%{_libdir}/%{name}/lmnet.so
%{_libdir}/%{name}/lmnetstrms.so
%{_libdir}/%{name}/lmnsd_ptcp.so
%{_libdir}/%{name}/lmregexp.so
%{_libdir}/%{name}/lmstrmsrv.so
%{_libdir}/%{name}/lmtcpclt.so
%{_libdir}/%{name}/lmtcpsrv.so
%{_libdir}/%{name}/lmzlibw.so
%{_libdir}/%{name}/ommail.so
%{_libdir}/%{name}/omruleset.so
%{_libdir}/%{name}/omtesting.so
%{_mandir}/man?/*
/etc/rc.d/init.d/%{name}
/etc/rc.d/rc2.d/S%{name}
/etc/rc.d/rc2.d/K%{name}
/etc/rc.d/rc3.d/S%{name}
/etc/rc.d/rc3.d/K%{name}
%dir /var/run


%files gssapi
%defattr(-,root,system)
%{_libdir}/%{name}/imgssapi.so
%{_libdir}/%{name}/lmgssutil.so
%{_libdir}/%{name}/omgssapi.so


%files relp
%defattr(-,root,system)
%{_libdir}/%{name}/imrelp.so
%{_libdir}/%{name}/omrelp.so


%files gnutls
%defattr(-,root,system)
%{_libdir}/%{name}/lmnsd_gtls.so


%changelog
* Wed Mar 09 2011 Michael Perzl <michael@perzl.org> - 5.6.4-1
- first version for AIX V5.1 and higher
